@@ -9,9 +9,8 @@
 #'   \item{y}{Continuous outcome}
 #'   \item{z}{Fully observed covariate, with linear effect on outcome}
 #'   \item{x}{Partially observed normally distributed covariate, with quadratic effect on outcome}
-#'   \item{xsq}{The square of x, which thus has missing values also}
 #'   \item{v}{An auxiliary variable (i.e. not contained in the substantive model)}
 #' }
 #'
-"ex_linquad"
+"linquad"
 
